ExitStatus

Enum ExitStatus 

pub enum ExitStatus {
    Code(i32),
    Signal(i32),
}
Describes the result of a process after it has terminated.

Variants



Code(i32)

Normal termination with an exit code.



Signal(i32)

Termination by signal, with the signal number.

Never generated on Windows.

Implementations

Source

impl ExitStatus

pub fn success(self) -> bool

Was termination successful? Signal termination not considered a success, and success is defined as a zero exit status.