ArcFileDescOpenerEnv

Struct ArcFileDescOpenerEnv 

pub struct ArcFileDescOpenerEnv<O> { /* private fields */ }
A FileDescOpener implementation which delegates to another implementation, but wraps any returned handles with in an Arc.

Implementations

Source

impl<O> ArcFileDescOpenerEnv<O>

pub fn new(opener: O) -> Self

Create a new wrapper instance around some other FileDescOpener implementation.