FileDescEnv

Struct FileDescEnv 

pub struct FileDescEnv<T> { /* private fields */ }
An environment module for setting and getting shell file descriptors.

Implementations

Source

impl<T> FileDescEnv<T>

pub fn new() -> Self

Constructs a new environment with no open file descriptors.

pub fn with_capacity(capacity: usize) -> Self

Constructs a new environment with no open file descriptors, but with a specified capacity for storing open file descriptors.

pub fn with_process_stdio() -> Result<Self>
where T: From<FileDesc>,

Constructs a new environment and initializes it with duplicated stdio file descriptors or handles of the current process.

pub fn with_fds<I: IntoIterator<Item = (Fd, T, Permissions)>>(iter: I) -> Self

Constructs a new environment with a provided collection of provided file descriptors in the form (shell_fd, handle, permissions).