pub struct Pipe<T> {
pub reader: T,
pub writer: T,
}Expand description
A pipe reader/writer pair created by a FileDescOpener.
Fields
reader: TThe reader end of the pipe. Anything written to the writer end can be read here.
writer: TThe writer end of the pipe. Anything written here can be read from the reader end.