TokioFileDescManagerEnv

Struct TokioFileDescManagerEnv 

pub struct TokioFileDescManagerEnv { /* private fields */ }
An environment implementation which manages opening, storing, and performing async I/O operations on file descriptor handles via tokio.

Implementations

Source

impl TokioFileDescManagerEnv

pub fn new() -> Self

Create a new environment using specific opener/storer/async implementations.

pub fn with_capacity(capacity: usize) -> Self

Constructs a new environment with no open file descriptors, but with a specified capacity for storing open file descriptors.

pub fn with_process_stdio() -> Result<Self>

Constructs a new environment and initializes it with duplicated stdio file descriptors or handles of the current process.