VarEnv

Struct VarEnv 

pub struct VarEnv<N: Eq + Hash, V> { /* private fields */ }
An environment module for setting, getting, and exporting shell variables.

Implementations

Source

impl<N, V> VarEnv<N, V>
where N: Eq + Hash,

pub fn new() -> Self

Constructs a new environment with no environment variables.

pub fn with_process_env_vars() -> Self
where N: From<String>, V: From<String>,

Constructs a new environment and initializes it with the environment variables of the current process.

pub fn with_env_vars<I: IntoIterator<Item = (N, V)>>(iter: I) -> Self

Constructs a new environment with a provided collection of (key, value) environment variable pairs. These variables (if any) will be inherited by all commands.