pub struct VirtualWorkingDirEnv { /* private fields */ }Expand description
An environment module for keeping track of the current working directory.
This is a “virtual” implementation because changing the working directory through this environment will not affect the working directory of the entire process.
Implementations
Sourceimpl VirtualWorkingDirEnv
impl VirtualWorkingDirEnv
Sourcepub fn new<P: AsRef<Path>>(path: P) -> Result<Self>
pub fn new<P: AsRef<Path>>(path: P) -> Result<Self>
Constructs a new environment with a provided working directory.
The specified path must be an absolute path or an error will result.
Sourcepub fn with_path_buf(path: PathBuf) -> Result<Self>
pub fn with_path_buf(path: PathBuf) -> Result<Self>
Constructs a new environment with a provided PathBuf as a working directory.
The specified path must be an absolute path or an error will result.
Sourcepub fn with_process_working_dir() -> Result<Self>
pub fn with_process_working_dir() -> Result<Self>
Constructs a new environment and initializes it with the current working directory of the current process.