pub trait FunctionFrameEnvironment {
// Required methods
fn push_fn_frame(&mut self);
fn pop_fn_frame(&mut self);
fn is_fn_running(&self) -> bool;
}Expand description
An interface for tracking the current stack of functions being executed.
Required Methods
Sourcefn push_fn_frame(&mut self)
fn push_fn_frame(&mut self)
Denote that a new function has been invoked and is currently executing.
Sourcefn pop_fn_frame(&mut self)
fn pop_fn_frame(&mut self)
Denote that a function has completed and is no longer executing.
Sourcefn is_fn_running(&self) -> bool
fn is_fn_running(&self) -> bool
Determines if there is at least one function being currently executed.