Module error

Module error 

A module defining the various kinds of errors that may arise while executing commands.

Enums

CommandError
An error which may arise when spawning a command process.
ExpansionError
An error which may arise during parameter expansion.
RedirectionError
An error which may arise during redirection.
RuntimeError
An error which may arise while executing commands.

Traits

IsFatalError
Determines whether an error should be treated as “fatal”.