pub enum CommandError {
NotFound(String),
NotExecutable(String),
Io(Error, Option<String>),
}Expand description
An error which may arise when spawning a command process.
Variants
NotFound(String)
Unable to find a command/function/builtin to execute.
NotExecutable(String)
Utility or script does not have executable permissions.
Io(Error, Option<String>)
Any I/O error returned by the OS during execution and the file that caused the error if applicable.