pub enum ExpansionError {
DivideByZero,
NegativeExponent,
BadAssig(String),
EmptyParameter(String, String),
}Expand description
An error which may arise during parameter expansion.
Variants
DivideByZero
Attempted to divide by zero in an arithmetic subsitution.
NegativeExponent
Attempted to raise to a negative power in an arithmetic subsitution.
BadAssig(String)
Attempted to assign a special parameter, e.g. ${!:=value}.
EmptyParameter(String, String)
Attempted to evaluate a null or unset parameter, i.e. ${var:?msg}.