pub enum RedirectAction<T> {
Close(Fd),
Open(Fd, T, Permissions),
HereDoc(Fd, Vec<u8>),
}Expand description
Indicates what changes should be made to the environment as a result
of a successful Redirect evaluation.
Variants
Close(Fd)
Indicates that a descriptor should be closed.
Open(Fd, T, Permissions)
Indicates that a descriptor should be opened with a given file handle and permissions.
HereDoc(Fd, Vec<u8>)
Indicates that the body of a heredoc should be asynchronously written to a file handle on a best effor basis (i.e. write as much of the body as possible but give up on appropriate errors such as broken pipes).
Implementations
Sourceimpl<T> RedirectAction<T>
impl<T> RedirectAction<T>
Sourcepub fn apply<E>(self, env: &mut E) -> Result<()>where
E: ?Sized + AsyncIoEnvironment + FileDescEnvironment + FileDescOpener,
E::FileHandle: From<T> + From<E::OpenedFileHandle>,
E::IoHandle: From<E::FileHandle>,
pub fn apply<E>(self, env: &mut E) -> Result<()>where
E: ?Sized + AsyncIoEnvironment + FileDescEnvironment + FileDescOpener,
E::FileHandle: From<T> + From<E::OpenedFileHandle>,
E::IoHandle: From<E::FileHandle>,
Applies changes to a given environment as appropriate.