pub enum RedirectOrCmdWord<R, W> {
Redirect(R),
CmdWord(W),
}Expand description
Represents a redirect or a command word.
Because the order in which redirects are defined may be significant for execution (i.e. due to side effects), we will process them in the order they were defined.
Variants
Redirect(R)
A redirect defined before a command name.
CmdWord(W)
A shell word, either command name or argument.