pub enum TildeExpansion {
None,
First,
All,
}Expand description
An enum representing how tildes (~) are expanded.
Variants
None
Tildes retain a literal value, no expansion is done.
First
Tildes are expanded if they are at the beginning of a word.
All
All tildes (either at start of word or after :) are expanded.