error

Function error 

pub async fn error<P, W, E>(
    strict: bool,
    param: &P,
    error: Option<W>,
    env: &mut E,
    cfg: TildeExpansion,
) -> Result<Fields<W::EvalResult>, W::Error>
where P: ?Sized + ParamEval<E, EvalResult = W::EvalResult> + Display, W: WordEval<E>, W::Error: From<ExpansionError>, E: ?Sized,
Evaluates a parameter or raises an error if it is empty.

First, param will be evaluated and returned as is as long as the result is non-empty, or if the result is defined-but-empty and strict = false.

Otherwise, error will be evaluated using cfg, and the result will populate an ExpansionError::EmptyParameter.

Note: field splitting will neither be done on the parameter, nor the error message.