FileDesc

Struct FileDesc 

pub struct FileDesc(/* private fields */);
A wrapper around an owned OS file primitive. The wrapper allows reading from or writing to the OS file primitive, and will close it once it goes out of scope.

Implementations

Source

impl FileDesc

pub unsafe fn new(fd: RawFd) -> Self

Constructs an FileDesc from the specified raw file descriptor.

Safety

This function consumes ownership of the specified file descriptor. The returned object will take responsibility for closing it when the object goes out of scope.

This function is also unsafe as the primitives currently returned have the contract that they are the sole owner of the file descriptor they are wrapping. Usage of this function could accidentally allow violating this contract which can cause memory unsafety in code that relies on it being true.

pub fn duplicate(&self) -> Result<Self>

Duplicates the underlying OS file primitive.

pub fn set_nonblock(&mut self, set: bool) -> Result<()>

Sets the O_NONBLOCK flag on the descriptor to the desired state.

Specifiying true will set the file descriptor in non-blocking mode, while specifying false will set it to blocking mode.