Pipe

Struct Pipe 

pub struct Pipe {
    pub reader: FileDesc,
    pub writer: FileDesc,
}
A wrapper for a reader and writer OS pipe pair.

Fields

reader: FileDesc

The reader end of the pipe. Anything written to the writer end can be read here.

writer: FileDesc

The writer end of the pipe. Anything written here can be read from the reader end.

Implementations

Source

impl Pipe

pub fn new() -> IoResult<Pipe>

Creates and returns a new pipe pair. On Unix systems, both file descriptors of the pipe will have their CLOEXEC flags set, however, note that the setting of the flags is nonatomic on BSD systems.