Module path

Module path 

Defines helpers and utilities for working with file system paths

Structs

NormalizationError
An error that can arise during physical path normalization.
NormalizedPath
A PathBuf wrapper which ensures paths do not have . or .. components.