Module spawn

Module spawn 

Defines methods for spawning commands into futures.

Modules

ast_impl
This module defines various Spawn implementations on AST types defined by the conch-parser crate.
builtin
Defines methods for spawning shell builtin commands

Structs

GuardBodyPair
A grouping of guard and body commands.
PatternBodyPair
A grouping of patterns and body commands.
SequenceSlice
Spawn adapter around a maybe owned slice of commands.

Enums

AndOr
A command which conditionally runs based on the exit status of the previous command.

Traits

Spawn
A trait for spawning commands.

Functions

and_or_list
Spawns an And/Or list of commands from an initial command and an iterator.
case
Spawns a case commands from a word to match number of case arms.
for_args
Spawns a for loop with the environment’s currently set arguments.
for_loop
Spawns a for loop with all the fields when words are evaluated.
for_with_args
Spawns a for loop with the specified arguments.
function
Creates a future adapter that will attempt to execute a function (if it has been defined) with a given set of arguments.
function_body
Creates a future adapter that will execute a function body with the given set of arguments.
if_cmd
Spawns an If commands from number of conditional branches.
loop_cmd
Spawns a loop command such as while or until using a guard and a body.
pipeline
Spawns a pipeline of commands.
sequence
Spawns any iterable collection of sequential items.
sequence_exact
Spawns an exact-size iterator of sequential items.
sequence_slice
Creates a Spawn adapter around a maybe owned slice of commands.
simple_command
Spawns a shell command (or function) after applying any redirects and environment variable assignments.
simple_command_with_restorer
Spawns a shell command (or function) after applying any redirects and environment variable assignments.
spawn_with_local_redirections_and_restorer
Evaluate a number of local redirects before spawning the inner command.
subshell
Spawns anything as if running in a subshell environment.
substitution
Spawns something whose standard output will be captured (and trailing newlines trimmed).
swallow_non_fatal_errors
Spawns a command and swallow (and report) all non-fatal errors and resolve to EXIT_ERROR if they arise.