for_loop

Function for_loop 

pub async fn for_loop<W, I, S, E>(
    name: E::VarName,
    words: I,
    body: S,
    env: &mut E,
) -> Result<BoxFuture<'static, ExitStatus>, S::Error>
where I: IntoIterator<Item = W>, W: WordEval<E>, S: Spawn<E>, S::Error: From<W::Error>, E: ?Sized + LastStatusEnvironment + VariableEnvironment, E::VarName: Clone, E::Var: From<W::EvalResult>,
Spawns a for loop with all the fields when words are evaluated.

For each element in the environment’s arguments, name will be assigned with its value and body will be executed.