loop_cmd

Function loop_cmd 

pub async fn loop_cmd<G, B, E>(
    invert_guard_status: bool,
    guard: G,
    body: B,
    env: &mut E,
) -> Result<ExitStatus, G::Error>
where G: Spawn<E>, B: Spawn<E, Error = G::Error>, E: ?Sized + LastStatusEnvironment,
Spawns a loop command such as while or until using a guard and a body.

The guard will be repeatedly executed and its exit status used to determine if the loop should be broken, or if the body should be executed. If invert_guard_status == false, the loop will continue as long as the guard exits successfully. If invert_guard_status == true, the loop will continue until the guard exits successfully.