pub fn sequence_slice<S>(cmds: &[S]) -> SequenceSlice<'_, S>Expand description
Creates a Spawn adapter around a maybe owned slice of commands.
Spawn behavior is the same as sequence_exact.
pub fn sequence_slice<S>(cmds: &[S]) -> SequenceSlice<'_, S>Creates a Spawn adapter around a maybe owned slice of commands.
Spawn behavior is the same as sequence_exact.