subshell

Function subshell 

pub fn subshell<S, E>(spawn: S, env: &E) -> impl Future<Output = ExitStatus>
where S: Spawn<E>, S::Error: 'static + Send + Sync + Error, E: ReportErrorEnvironment + SubEnvironment,
Spawns anything as if running in a subshell environment.

The env parameter will be copied as a SubEnvironment, in whose context the commands will be executed.