pub struct GuardBodyPair<T> {
pub guard: T,
pub body: T,
}Expand description
A grouping of guard and body commands.
Fields
guard: TThe guard commands, which if successful, should lead to the execution of the body commands.
body: TThe body commands to execute if the guard is successful.