pub struct Env<A, FM, L, V, EX, WD, B, N: Eq + Hash, ERR> { /* private fields */ }Expand description
A shell environment implementation which delegates work to other environment implementations.
Implementations
Sourceimpl<A, FM, L, V, EX, WD, B, N, ERR> Env<A, FM, L, V, EX, WD, B, N, ERR>
impl<A, FM, L, V, EX, WD, B, N, ERR> Env<A, FM, L, V, EX, WD, B, N, ERR>
Sourcepub fn with_config(cfg: EnvConfig<A, FM, L, V, EX, WD, B, N, ERR>) -> Self
pub fn with_config(cfg: EnvConfig<A, FM, L, V, EX, WD, B, N, ERR>) -> Self
Creates an environment using the provided configuration of subcomponents.
See EnvConfig for the kinds of overrides possible. DefaultEnvConfig
comes with provided implementations to get you up and running.
General recommendations:
- The result of evaluating a shell word will often be copied and reused
in many different places. It’s strongly recommened that an
Arcwrapper (e.g.Arc<String>) is used to minimize having to reallocate and copy the same data. - Whatever type represents a shell function body needs to be cloned to
get around borrow restrictions and potential recursive executions and
(re-)definitions. Since this type is probably an AST (which may be
arbitrarily large),
Arcis your friend.
Sourceimpl<T> Env<ArgsEnv<T>, TokioFileDescManagerEnv, LastStatusEnv, VarEnv<T, T>, TokioExecEnv, VirtualWorkingDirEnv, BuiltinEnv<T>, T, RuntimeError>where
T: StringWrapper,
impl<T> Env<ArgsEnv<T>, TokioFileDescManagerEnv, LastStatusEnv, VarEnv<T, T>, TokioExecEnv, VirtualWorkingDirEnv, BuiltinEnv<T>, T, RuntimeError>where
T: StringWrapper,