pub struct ExecutableData<'a> {
pub name: &'a OsStr,
pub args: &'a [&'a OsStr],
pub env_vars: &'a [(&'a OsStr, &'a OsStr)],
pub current_dir: &'a Path,
pub stdin: Option<FileDesc>,
pub stdout: Option<FileDesc>,
pub stderr: Option<FileDesc>,
}Expand description
Any data required to execute a child process.
Fields
name: &'a OsStrThe name/path to the executable.
args: &'a [&'a OsStr]Arguments to be provided to the executable.
env_vars: &'a [(&'a OsStr, &'a OsStr)]Any environment variables that should be passed to the executable. Environment variables from the current process must NOT be inherited if they do not appear in this collection.
current_dir: &'a PathThe current working directory the executable should start out with.
stdin: Option<FileDesc>The executable’s standard input will be redirected to this descriptor
or the equivalent of /dev/null if not specified.
stdout: Option<FileDesc>The executable’s standard output will be redirected to this descriptor
or the equivalent of /dev/null if not specified.
stderr: Option<FileDesc>The executable’s standard error will be redirected to this descriptor
or the equivalent of /dev/null if not specified.