pub struct FileDescEnv<T> { /* private fields */ }Expand description
An environment module for setting and getting shell file descriptors.
Implementations
Sourceimpl<T> FileDescEnv<T>
impl<T> FileDescEnv<T>
Sourcepub fn with_capacity(capacity: usize) -> Self
pub fn with_capacity(capacity: usize) -> Self
Constructs a new environment with no open file descriptors, but with a specified capacity for storing open file descriptors.
Sourcepub fn with_process_stdio() -> Result<Self>
pub fn with_process_stdio() -> Result<Self>
Constructs a new environment and initializes it with duplicated stdio file descriptors or handles of the current process.
Sourcepub fn with_fds<I: IntoIterator<Item = (Fd, T, Permissions)>>(iter: I) -> Self
pub fn with_fds<I: IntoIterator<Item = (Fd, T, Permissions)>>(iter: I) -> Self
Constructs a new environment with a provided collection of provided
file descriptors in the form (shell_fd, handle, permissions).