pub struct VarEnv<N: Eq + Hash, V> { /* private fields */ }Expand description
An environment module for setting, getting, and exporting shell variables.
Implementations
Sourceimpl<N, V> VarEnv<N, V>
impl<N, V> VarEnv<N, V>
Sourcepub fn with_process_env_vars() -> Self
pub fn with_process_env_vars() -> Self
Constructs a new environment and initializes it with the environment variables of the current process.
Sourcepub fn with_env_vars<I: IntoIterator<Item = (N, V)>>(iter: I) -> Self
pub fn with_env_vars<I: IntoIterator<Item = (N, V)>>(iter: I) -> Self
Constructs a new environment with a provided collection of (key, value)
environment variable pairs. These variables (if any) will be inherited by
all commands.