FunctionFrameEnvironment

Trait FunctionFrameEnvironment 

pub trait FunctionFrameEnvironment {
    // Required methods
    fn push_fn_frame(&mut self);
    fn pop_fn_frame(&mut self);
    fn is_fn_running(&self) -> bool;
}
An interface for tracking the current stack of functions being executed.

Required Methods

fn push_fn_frame(&mut self)

Denote that a new function has been invoked and is currently executing.

fn pop_fn_frame(&mut self)

Denote that a function has completed and is no longer executing.

fn is_fn_running(&self) -> bool

Determines if there is at least one function being currently executed.

Implementations on Foreign Types

Source

impl<'a, T: ?Sized + FunctionFrameEnvironment> FunctionFrameEnvironment for &'a mut T

Implementors

Source

impl FunctionFrameEnvironment for FnFrameEnv

Source

impl<A, FM, L, V, EX, WD, B, N, ERR> FunctionFrameEnvironment for Env<A, FM, L, V, EX, WD, B, N, ERR>
where N: Hash + Eq + Clone,