pub type DefaultEnvConfig<T> = EnvConfig<ArgsEnv<T>, TokioFileDescManagerEnv, LastStatusEnv, VarEnv<T, T>, TokioExecEnv, VirtualWorkingDirEnv, BuiltinEnv<T>, T, RuntimeError>;Expand description
A default environment configuration using provided (non-atomic) implementations,
and powered by tokio.
Generic over the representation of shell words, variables, function names, etc.
Aliased Type
pub struct DefaultEnvConfig<T> {
pub interactive: bool,
pub args_env: ArgsEnv<T>,
pub file_desc_manager_env: TokioFileDescManagerEnv,
pub last_status_env: LastStatusEnv,
pub var_env: VarEnv<T, T>,
pub exec_env: TokioExecEnv,
pub working_dir_env: VirtualWorkingDirEnv,
pub builtin_env: BuiltinEnv<T>,
pub fn_name: PhantomData<T>,
pub fn_error: PhantomData<RuntimeError>,
}Fields
interactive: boolSpecify if the environment is running in interactive mode.
args_env: ArgsEnv<T>An implementation of ArgumentsEnvironment and possibly SetArgumentsEnvironment.
file_desc_manager_env: TokioFileDescManagerEnvAn implementation of FileDescManagerEnvironment.
last_status_env: LastStatusEnvAn implementation of LastStatusEnvironment.
var_env: VarEnv<T, T>An implementation of VariableEnvironment, UnsetVariableEnvironment, and
ExportedVariableEnvironment.
exec_env: TokioExecEnvAn implementation of ExecutableEnvironment.
working_dir_env: VirtualWorkingDirEnvAn implementation of WorkingDirectoryEnvironment.
builtin_env: BuiltinEnv<T>An implementation of BuiltinEnvironment.
fn_name: PhantomData<T>A marker to indicate the type used for function names.
fn_error: PhantomData<RuntimeError>A marker to indicate the type used for function errors.