A module defining the various kinds of errors that may arise while executing commands.
Enums
- Command
Error - An error which may arise when spawning a command process.
- Expansion
Error - An error which may arise during parameter expansion.
- Redirection
Error - An error which may arise during redirection.
- Runtime
Error - An error which may arise while executing commands.
Traits
- IsFatal
Error - Determines whether an error should be treated as “fatal”.