pub struct Pipe {
pub reader: FileDesc,
pub writer: FileDesc,
}Expand description
A wrapper for a reader and writer OS pipe pair.
Fields
reader: FileDescThe reader end of the pipe. Anything written to the writer end can be read here.
writer: FileDescThe writer end of the pipe. Anything written here can be read from the reader end.
Implementations