Defines methods for spawning commands into futures.
Modules
- ast_
impl - This module defines various
Spawnimplementations on AST types defined by theconch-parsercrate. - builtin
- Defines methods for spawning shell builtin commands
Structs
- Guard
Body Pair - A grouping of guard and body commands.
- Pattern
Body Pair - A grouping of patterns and body commands.
- Sequence
Slice Spawnadapter around a maybe owned slice of commands.
Enums
- AndOr
- A command which conditionally runs based on the exit status of the previous command.
Traits
- Spawn
- A trait for spawning commands.
Functions
- and_
or_ list - Spawns an
And/Orlist of commands from an initial command and an iterator. - case
- Spawns a
casecommands from a word to match number of case arms. - for_
args - Spawns a
forloop with the environment’s currently set arguments. - for_
loop - Spawns a
forloop with all the fields whenwordsare evaluated. - for_
with_ args - Spawns a
forloop with the specified arguments. - function
- Creates a future adapter that will attempt to execute a function (if it has been defined) with a given set of arguments.
- function_
body - Creates a future adapter that will execute a function body with the given set of arguments.
- if_cmd
- Spawns an
Ifcommands from number of conditional branches. - loop_
cmd - Spawns a loop command such as
whileoruntilusing a guard and a body. - pipeline
- Spawns a pipeline of commands.
- sequence
- Spawns any iterable collection of sequential items.
- sequence_
exact - Spawns an exact-size iterator of sequential items.
- sequence_
slice - Creates a
Spawnadapter around a maybe owned slice of commands. - simple_
command - Spawns a shell command (or function) after applying any redirects and environment variable assignments.
- simple_
command_ with_ restorer - Spawns a shell command (or function) after applying any redirects and environment variable assignments.
- spawn_
with_ local_ redirections_ and_ restorer - Evaluate a number of local redirects before spawning the inner command.
- subshell
- Spawns anything as if running in a subshell environment.
- substitution
- Spawns something whose standard output will be captured (and trailing newlines trimmed).
- swallow_
non_ fatal_ errors - Spawns a command and swallow (and report) all non-fatal errors
and resolve to
EXIT_ERRORif they arise.